#ifndef __ANIMAL_H__
#define __ANIMAL_H__
#include "veterinario.h"
#include "tratador.h"

#include <iostream>
#include <string>
#include <fstream>

using namespace std;

/* @brief Classe Animal, que modela um ser animal
* @param 	Atributos protegidos:
* 				id - identificador do animal,
*					classe - classe do animal
* 				nome - nome genérico do animal
*					cientifico - nome cientifico do animal
* 				sexo - sexo do animal,
*					tamanho - tamanho do animal
* 				dieta - de que o animal se alimenta
*					batismo - nome de batismo do animal
*					veterinario - veterinario ao qual o animal está associado
*					tratador - tratador ao qual o animal está associado
*					Metodo protegido:
*					virtual std::ostream& print(std::ostream&) const = 0;

*					Métodos públicos:
*					getId - retorna o id do animal
*					setId - modifica o id do animal
*					getNome - retorna o nome do animal
*					setNome - modifica o nome do animal
*					getCientifico - retorna o nome cientifico do animal
*					setCientifico - modifica o nome cientifico do animal
*					getSexo- retorna o sexo do animal
*					setSexo - modifica o sexo do animal
*					getTamanho - retorna o tamanho do animal
*					setTamanho - modifica o tamanho do animal
*					getDieta - retorna a dieta do animal
*					setDieta - modifica a dieta do animal
*					getVeterinario - retorna o veterinario do animal
*					setVeterinario - modifica o veterinario do animal
*					getTratador - retorna o tratador do animal
*					setTratador - modifica o tratador do animal
*					Animal - Construtor cria um ser do tipo Animal, inicializando os seus atributos
*					virtual void imprime()=0 - método para impressão das informações do animal
*
*/
class Animal {
	private:
		virtual std::ostream& print(std::ostream&) const = 0;

	protected:
		int id;
		string classe;
		string nome;
		string cientifico;
		char sexo;
		float tamanho;
		string dieta;
		string batismo;
		Veterinario veterinario;
		Tratador tratador;


	public:
		int getId();
		void setId(int identity);
		string getClasse();
		void setClasse(string clas);
		string getNome();
		void setNome(string name);
		string getCientifico();
		void setCientifico(string scientific);
		char getSexo();
		void setSexo(char sex);
		float getTamanho();
		void setTamanho(float size);
		string getDieta();
		void setDieta(string diet);
		string getBatismo();
		void setBatismo(string baptism);
		Veterinario getVeterinario();
		void setVeterinario(Veterinario vet);
		Tratador getTratador();
		void setTratador(Tratador caretaker);
		friend std::ostream& operator << (std::ostream& output, const Animal& a) {
    	return a.print(output); // polymorphic print via reference
    }
		Animal(int identity, string clas, string name, string scientific, char sex, float size, string diet, string baptism, Veterinario vet, Tratador caretaker);
};


#endif
